@@ -106,6 +106,13 @@ public class Stapler extends HttpServlet {
      */
     private volatile Map<String,URL> resourcePaths;
 
+    /**
+     * Temporarily updates the thread name to reflect the request being processed.
+     * On by default for convenience, but for webapps that use filters, use
+     * {@link DiagnosticThreadNameFilter} as the first filter and switch this off.
+     */
+    private boolean diagnosticThreadName = true;
+
 
     public @Override void init(ServletConfig servletConfig) throws ServletException {
         super.init(servletConfig);
@@ -122,6 +129,10 @@ public class Stapler extends HttpServlet {
         }
         buildResourcePaths();
         webApp.addStaplerServlet(servletConfig.getServletName(),this);
+
+        String v = servletConfig.getInitParameter("diagnosticThreadName");
+        if (v!=null)
+            diagnosticThreadName = Boolean.parseBoolean(v);
     }
 
     /**
@@ -174,7 +185,8 @@ public class Stapler extends HttpServlet {
         Thread t = Thread.currentThread();
         final String oldName = t.getName();
         try {
-            t.setName("Handling "+req.getMethod()+' '+req.getRequestURI()+" : "+oldName);
+            if (diagnosticThreadName)
+                t.setName("Handling "+req.getMethod()+' '+req.getRequestURI()+" : "+oldName);
 
             String servletPath = getServletPath(req);
 
@@ -507,6 +519,11 @@ public class Stapler extends HttpServlet {
             String mimeType = getMimeType(fileName);
             rsp.setContentType(mimeType);
 
+            // use nosniff to enforce the content type we are setting above, instead of letting browser
+            // guess it on its own. I found http://security.stackexchange.com/questions/12896/
+            // a comprehensive discussion on this topic
+            rsp.setHeader("X-Content-Type-Options","nosniff");
+
             int idx = fileName.lastIndexOf('.');
             String ext = fileName.substring(idx+1);
 
