@@ -90,6 +90,15 @@ public class WebApp {
      */
     public final List<Facet> facets = new Vector<Facet>();
 
+    /**
+     * Global {@link BindInterceptor}s.
+     *
+     * These are consulted after {@link StaplerRequest#getBindInterceptor()} is consulted.
+     * Global bind interceptors are useful to register webapp-wide conversion logic local to the application.
+     * @since 1.220
+     */
+    public final List<BindInterceptor> bindInterceptors = new CopyOnWriteArrayList<BindInterceptor>();
+
     /**
      * MIME type mapping from extensions (like "txt" or "jpg") to MIME types ("foo/bar").
      *
