@@ -118,7 +118,11 @@ public class BoundObjectTable implements StaplerFallback {
             final Object target = ref.get();
             if (target instanceof WithWellKnownURL) {
                 WithWellKnownURL w = (WithWellKnownURL) target;
-                return new WellKnownObjectHandle(w.getWellKnownUrl(),w);
+                String url = w.getWellKnownUrl();
+                if (!url.startsWith("/")) {
+                    LOGGER.warning("WithWellKnownURL.getWellKnownUrl must start with a slash. But we got " + url + " from "+w);
+                }
+                return new WellKnownObjectHandle(url, w);
             }
 
             final String id = UUID.randomUUID().toString();
