@@ -25,6 +25,8 @@ package org.kohsuke.stapler.export;
 
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
+import javax.annotation.CheckForNull;
+import javax.annotation.Nullable;
 
 /**
  * Creates and maintains {@link Model}s, that are used to write out
@@ -39,10 +41,14 @@ public class ModelBuilder {
      */
     /*package*/ final Map<Class, Model> models = new ConcurrentHashMap<Class, Model>();
 
-    public <T> Model<T> get(Class<T> type) {
+    public <T> Model<T> get(Class<T> type) throws NotExportableException {
+        return get(type, null, null);
+    }
+
+    public <T> Model<T> get(Class<T> type, @CheckForNull Class<?> propertyOwner, @Nullable String property) throws NotExportableException {
         Model m = models.get(type);
         if(m==null) {
-            m = new Model<T>(this,type);
+            m = new Model<T>(this, type, propertyOwner, property);
         }
         return m;
     }
