@@ -95,6 +95,13 @@ public class AdjunctsInPage {
         return Collections.unmodifiableSet(included);
     }
 
+    /**
+     * Checks if something has already been included/assumed.
+     */
+    public boolean isIncluded(String include) {
+        return included.contains(include);
+    }
+
     /**
      * Generates the script tag and CSS link tag to include necessary adjuncts,
      * and records the fact that those adjuncts are already included in the page,
